The filesystem implementation is a concrete implementation of the abstract copick API that reads data from the [cryoET
Data Portal](https://cryoetdataportal.czscience.com/) and reads/writes data to/from any storage supported by `fsspec`.
The filesystem implementation is defined in the `copick.impl.cryoet_data_portal` module.

## Metadata Models

[](){#CopickConfigCDP}
::: copick.impl.cryoet_data_portal.CopickConfigCDP


## Data Entities

[](){#CopickRootCDP}
::: copick.impl.cryoet_data_portal.CopickRootCDP

****

[](){#CopickObjectCDP}
::: copick.impl.cryoet_data_portal.CopickObjectCDP

****

[](){#CopickRunCDP}
::: copick.impl.cryoet_data_portal.CopickRunCDP

****

[](){#CopickPicksCDP}
::: copick.impl.cryoet_data_portal.CopickPicksCDP

****

[](){#CopickMeshCDP}
::: copick.impl.cryoet_data_portal.CopickMeshCDP

****

[](){#CopickSegmentationCDP}
::: copick.impl.cryoet_data_portal.CopickSegmentationCDP

****

[](){#CopickVoxelSpacingCDP}
::: copick.impl.cryoet_data_portal.CopickVoxelSpacingCDP

****

[](){#CopickTomogramCDP}
::: copick.impl.cryoet_data_portal.CopickTomogramCDP

****

[](){#CopickFeaturesCDP}
::: copick.impl.cryoet_data_portal.CopickFeaturesCDP
